@@ -28,7 +28,7 @@
 #' @inheritParams fast_scraper
 #' @param decode If `TRUE`, the function [decode_player_ids()] will be executed.
 #' @param rules If `FALSE`, printing of the header and footer in the console output will be suppressed.
-#' @return An nflfastR play-by-play data frame like it can be loaded from <https://github.com/guga31bb/nflfastR-data>.
+#' @return An nflfastR play-by-play data frame like it can be loaded from <https://github.com/nflverse/nflfastR-data>.
 #' @details To load valid game_ids please use the package function [fast_scraper_schedules()].
 #' @seealso For information on parallel processing and progress updates please
 #' see [nflfastR].
@@ -69,21 +69,21 @@ build_nflfastR_pbp <- function(game_ids,
     lifecycle::deprecate_warn(
       when = "4.0.0",
       what = "build_nflfastR_pbp(pp = )",
-      details = glue::glue(
+      details = cli::cli_text(c(
         "We have dropped the in-package activation of parallel processing as ",
         "this is considered bad practice.\n",
         "Please choose an appropriate plan before calling the function, e.g. ",
-        "{usethis::ui_code('future::plan(\"multisession\")')}"
-      )
+        "{.code future::plan(\"multisession\")}"
+      ))
     )
   }
 
   if (!is.vector(game_ids) && is.data.frame(game_ids)) game_ids <- game_ids$game_id
 
-  if (!is.vector(game_ids)) usethis::ui_stop("Param {usethis::ui_code('game_ids')} is not a valid vector!")
+  if (!is.vector(game_ids)) cli::cli_abort("Param {.code game_ids} is not a valid vector!")
 
   if (isTRUE(decode) && !is_installed("gsisdecoder")) {
-    usethis::ui_stop("Package {usethis::ui_value('gsisdecoder')} required for decoding. Please install it with {usethis::ui_code('install.packages(\"gsisdecoder\")')}.")
+    cli::cli_abort("Package {.val gsisdecoder} required for decoding. Please install it with {.code install.packages(\"gsisdecoder\")}.")
   }
 
   if (isTRUE(rules)) rule_header("Build nflfastR Play-by-Play Data")
@@ -92,9 +92,9 @@ build_nflfastR_pbp <- function(game_ids,
   builder <- TRUE
 
   if (game_count > 1) {
-    usethis::ui_todo("{my_time()} | Start download of {game_count} games...")
+    cli::cli_ul("{my_time()} | Start download of {game_count} games...")
   } else {
-    usethis::ui_todo("{my_time()} | Start download of {game_count} game...")
+    cli::cli_ul("{my_time()} | Start download of {game_count} game...")
   }
 
   ret <- fast_scraper(game_ids = game_ids, source = source, pp = pp, ..., in_builder = builder) %>%
