@@ -11,7 +11,7 @@
 get_pbp_gc <- function(gameId, dir = NULL, qs = FALSE) {
 
   if (isTRUE(qs) && !is_installed("qs")) {
-    usethis::ui_stop("Package {usethis::ui_value('qs')} required for argument {usethis::ui_value('qs = TRUE')}. Please install it.")
+    cli::cli_abort("Package {.val qs} required for argument {.val qs = TRUE}. Please install it.")
   }
 
   combined <- data.frame()
