@@ -14,7 +14,7 @@
 #' see [nflfastR].
 #' @examples
 #' \donttest{
-#' pbp <- load_pbp(2019:2020, qs = TRUE)
+#' pbp <- load_pbp(2019:2020)
 #' dplyr::glimpse(pbp)
 #' }
 #' @export
@@ -24,19 +24,19 @@ load_pbp <- function(seasons, ..., qs = FALSE) {
   if (all(c("dbConnection", "tablename") %in% names(dots))) in_db <- TRUE else in_db <- FALSE
 
   if (isTRUE(qs) && !is_installed("qs")) {
-    usethis::ui_stop("Package {usethis::ui_value('qs')} required for argument {usethis::ui_value('qs = TRUE')}. Please install it.")
+    cli::cli_abort("Package {.val qs} required for argument {.val qs = TRUE}. Please install it.")
   }
 
   most_recent <- most_recent_season()
 
   if (!all(seasons %in% 1999:most_recent)) {
-    usethis::ui_stop("Please pass valid seasons between 1999 and {most_recent}")
+    cli::cli_abort("Please pass valid seasons between 1999 and {most_recent}")
   }
 
   if (length(seasons) > 1 && is_sequential() && isFALSE(in_db)) {
-    usethis::ui_info(c(
-      "It is recommended to use parallel processing when trying to load multiple seasons.",
-      "Please consider running {usethis::ui_code('future::plan(\"multisession\")')}!",
+    cli::cli_alert_info(c(
+      "It is recommended to use parallel processing when trying to load multiple seasons.\n",
+      "Please consider running {.code future::plan(\"multisession\")}! ",
       "Will go on sequentially..."
     ))
   }
@@ -58,11 +58,11 @@ load_pbp <- function(seasons, ..., qs = FALSE) {
 # Helper function that is called by load_pbp above
 single_season <- function(season, p, dbConnection = NULL, tablename = NULL, qs = FALSE) {
   if (isTRUE(qs)) {
-    .url <- glue::glue("https://github.com/guga31bb/nflfastR-data/blob/master/data/play_by_play_{season}.qs?raw=true")
+    .url <- glue::glue("https://github.com/nflverse/nflfastR-data/blob/master/data/play_by_play_{season}.qs?raw=true")
     pbp <- qs_from_url(.url)
   }
   if (isFALSE(qs)) {
-    .url <- glue::glue("https://github.com/guga31bb/nflfastR-data/blob/master/data/play_by_play_{season}.rds?raw=true")
+    .url <- glue::glue("https://github.com/nflverse/nflfastR-data/blob/master/data/play_by_play_{season}.rds?raw=true")
     con <- url(.url)
     pbp <- readRDS(con)
     close(con)
